;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "finito" "20250907.1936"
  "View and collect books."
  '((emacs     "27.1")
    (dash      "2.19.1")
    (request   "0.3.2")
    (f         "0.2.0")
    (s         "1.12.0")
    (transient "0.3.0")
    (graphql   "0.1.1")
    (async     "1.9.3"))
  :url "https://github.com/LaurenceWarne/finito.el"
  :commit "be1c866c288bb0d92a24f8b5d4b64ea4d70355ef"
  :revdesc "be1c866c288b"
  :keywords '("outlines"))
